package File::Assets::ButMaintained;
{
  $File::Assets::ButMaintained::VERSION = '0.133070';
}

use strict;
use Class::Method::Modifiers qw(install_modifier);
use File::Assets;

#method _include_empty_assets () {
#    # 空のcssとjsファイルを読みこんでいる。
#    # File::AssetのCPANの最新バージョンは 0.064 だが、これにはバグがある模様。
#    # 検証用コードは share/bug-file-asset.t
#    # 一つもinclude_pathせずに、include_contentだけだとexportしたときに
#    # minifyの内容がファイルへ書かれない。
#    # githubのバージョン https://github.com/robertkrimen/file-assets b07fdd8fa163c1fa98b476ae36603941aaee0633 
#    # では、リファクタリング後のもののためか、このバグは再現しなかった。
#    # ここでは、CPANのバージョンのものでもこのバグが起きないように、空のファイルを読みこむ。
#    unless ( $c->debug ) { # minify したいのなら
#	$c->assets->include_path("css/empty.css");
#	$c->assets->include_path("js/empty.js");
#    }
#}
# 上のbugをfix.

unless ($File::Assets::VERSION > 0.064) {
    require File::Assets::Filter::Collect;
    install_modifier 'File::Assets::Filter::Collect', 'around', 'should_build' => sub {
        my $orig = shift;
        my $self = shift;

        return 1 unless -e $self->output_asset->file && -s _;
        $self->$orig;
    };

    install_modifier 'File::Assets', 'around', 'include_content' => sub {
        my $orig = shift;
        my $self = shift;

        my $opt;
        for (my$i=0; $i<=$#_; $i++) {
            if (ref($_[$i]) and ref($_[$i]) eq 'HASH') {
                $opt = splice(@_, $i, 1);
                last;
            }
        }
        $opt ||= {};

        unless ( exists $opt->{inline} ) {
            my $minify = (grep { $_->signature =~ m/^minifier/ } @{$self->{filter_scheme}{'*'}}) ? 1 : 0;
            $opt->{inline} = $minify ? 0 : 1;
        }

        $self->$orig(@_, $opt);
    };
}

1;

__END__

=pod

=head1 NAME

File::Assets::ButMaintained

=head1 VERSION

version 0.133070

=head1 AUTHOR

Tomohiro Hosaka <bokutin@bokut.in>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2013 by Tomohiro Hosaka.  No
license is granted to other entities.

=cut
